@@ -17,6 +17,39 @@ class Changelog:
 
     def initLogs(self) -> None:
         """Fill the changelog."""
+        self.logs.append(
+            ChangelogEntry(5, 24, 0)
+            .addLine("PROMPT INJECTION UPDATE")
+            .addLine("---")
+            .addLine("So basically, there are 8 new variables:")
+            .addLine("6 message injectors (string):")
+            .addLine("- pre_user / pre_assistant / pre_system")
+            .addLine("  ^ these will be prefixing each message from their role")
+            .addLine("- post_user / post_assistant / post_system")
+            .addLine("  ^ these will be suffixing each message from their role")
+            .addLine("2 history injectors (list of message dicts):")
+            .addLine("- pre_history / post_history")
+            .addLine('Basically, each message dict must contain a "role" key')
+            .addLine('  and a "content" key.')
+            .addLine('  "role" should be one of: user/assistant/system')
+            .addLine('  and "content is the actual message content"')
+            .addLine("You can just take a message history dict from a /save,")
+            .addLine("  these are loaded the same.")
+            .addLine("")
+            .addLine("Note that history injectors won't be affected by message")
+            .addLine("  injectors!")
+        )
+
+        self.logs.append(
+            ChangelogEntry(5, 23, 3)
+            .addLine("Changed TTS requirements: pygame not needed anymore,")
+            .addLine("  now requiring soundfile and sounddevice")
+        )
+        self.logs.append(
+            ChangelogEntry(5, 23, 2)
+            .addLine("Added optional argument to /reprint to only reprint N")
+            .addLine("  last messages.")
+        )
         self.logs.append(
             ChangelogEntry(5, 23, 1)
             .addLine("Added /lts command to enable/disable long term souvenirs")
@@ -24,7 +57,6 @@ class Changelog:
             .addLine("  as a function to be called by the AI.")
             .addLine("This should not have been hardcoded in the first place.")
         )
-
         self.logs.append(
             ChangelogEntry(5, 23, 0)
             .addLine("Added /web command to enable/disable")
